#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from z3c.form import field
from z3c.form.browser.checkbox import SingleCheckBoxFieldWidget

from pyams_form.form import ajax_config
from pyams_form.group import NamedWidgetsGroup
from pyams_pagelet.pagelet import pagelet_config
from pyams_skin.interfaces.extension import IFacebookSiteInfo, IGoogleAnalyticsInfo, \
    IGoogleTagManagerInfo, IUserReportInfo
from pyams_skin.layer import IPyAMSLayer
from pyams_skin.viewlet.menu import MenuDivider, MenuItem
from pyams_utils.interfaces import MANAGE_SYSTEM_PERMISSION
from pyams_utils.interfaces.site import ISiteRoot
from pyams_viewlet.viewlet import viewlet_config
from pyams_zmi import _
from pyams_zmi.form import AdminDialogEditForm
from pyams_zmi.interfaces.menu import IPropertiesMenu
from pyams_zmi.layer import IAdminLayer


@viewlet_config(name='extensions-divider.menu', context=ISiteRoot, layer=IAdminLayer,
                manager=IPropertiesMenu, permission=MANAGE_SYSTEM_PERMISSION, weight=799)
class ExtensionsMenuDivider(MenuDivider):
    """Extensions menu divider"""


#
# Google Tag Manager views
#

@viewlet_config(name='tag-manager-properties.menu', context=ISiteRoot, layer=IAdminLayer,
                manager=IPropertiesMenu, permission=MANAGE_SYSTEM_PERMISSION, weight=800)
class GoogleTagManagerPropertiesMenuItem(MenuItem):
    """Google Tag Manager properties menu"""

    label = _("Google Tag Manager...")
    icon_class = 'fa-tags'
    url = 'tag-manager-properties.html'
    modal_target = True


@pagelet_config(name='tag-manager-properties.html', context=ISiteRoot, layer=IPyAMSLayer,
                permission=MANAGE_SYSTEM_PERMISSION)
@ajax_config(name='tag-manager-properties.json', context=ISiteRoot, layer=IPyAMSLayer)
class GoogleTagManagerPropertiesEditForm(AdminDialogEditForm):
    """Google Tag Manager properties edit form"""

    prefix = 'tag_manager_properties.'

    legend = _("Update Google Tag Manager properties")
    edit_permission = MANAGE_SYSTEM_PERMISSION

    fields = field.Fields(IGoogleTagManagerInfo)
    fields['on_accepted_cookie'].widgetFactory = SingleCheckBoxFieldWidget

    label_css_class = 'control-label col-md-4'
    input_css_class = 'col-md-8'

    def updateGroups(self):
        self.add_group(NamedWidgetsGroup(self, 'cookie_accept', self.widgets,
                                         ('on_accepted_cookie', 'cookie_name', 'rejected_cookie_value'),
                                         legend=_("Activate only if not rejected cookies"),
                                         css_class='inner',
                                         help=_("If you have a cookie acceptance banner allowing your website users "
                                                "to accept or deny cookies, this extension will be activated only if "
                                                "cookies have not been rejected."),
                                         switch=True,
                                         checkbox_switch=True,
                                         checkbox_field=IGoogleTagManagerInfo['on_accepted_cookie']))
        self.add_group(NamedWidgetsGroup(self, 'container_id', self.widgets,
                                         ('container_id', 'activation_mode')))
        super(GoogleTagManagerPropertiesEditForm, self).updateGroups()


#
# Google Analytics views
#

@viewlet_config(name='analytics-properties.menu', context=ISiteRoot, layer=IAdminLayer,
                manager=IPropertiesMenu, permission=MANAGE_SYSTEM_PERMISSION, weight=810)
class GoogleAnalyticsPropertiesMenuItem(MenuItem):
    """Google Analytics properties menu"""

    label = _("Google Analytics...")
    icon_class = 'fa-line-chart'
    url = 'analytics-properties.html'
    modal_target = True


@pagelet_config(name='analytics-properties.html', context=ISiteRoot, layer=IPyAMSLayer,
                permission=MANAGE_SYSTEM_PERMISSION)
@ajax_config(name='analytics-properties.json', context=ISiteRoot, layer=IPyAMSLayer)
class GoogleAnalyticsPropertiesEditForm(AdminDialogEditForm):
    """Google Analytics properties edit form"""

    prefix = 'analytics_properties.'

    legend = _("Update Google Analytics properties")
    edit_permission = MANAGE_SYSTEM_PERMISSION

    fields = field.Fields(IGoogleAnalyticsInfo)
    fields['on_accepted_cookie'].widgetFactory = SingleCheckBoxFieldWidget

    label_css_class = 'control-label col-md-4'
    input_css_class = 'col-md-8'

    def updateGroups(self):
        self.add_group(NamedWidgetsGroup(self, 'cookie_accept', self.widgets,
                                         ('on_accepted_cookie', 'cookie_name', 'rejected_cookie_value'),
                                         legend=_("Activate only if not rejected cookies"),
                                         css_class='inner',
                                         help=_("If you have a cookie acceptance banner allowing your website users "
                                                "to accept or deny cookies, this extension will be activated only if "
                                                "cookies have not been rejected."),
                                         switch=True,
                                         checkbox_switch=True,
                                         checkbox_field=IGoogleAnalyticsInfo['on_accepted_cookie']))
        self.add_group(NamedWidgetsGroup(self, 'website_id', self.widgets,
                                         ('website_id', 'activation_mode')))
        super(GoogleAnalyticsPropertiesEditForm, self).updateGroups()


#
# UserReport views
#

@viewlet_config(name='user-report.menu', context=ISiteRoot, layer=IAdminLayer,
                manager=IPropertiesMenu, permission=MANAGE_SYSTEM_PERMISSION, weight=820)
class UserReportPropertiesMenuItem(MenuItem):
    """UserReport properties menu"""

    label = _("UserReport settings...")
    icon_class = 'fa-comments'
    url = 'user-report-properties.html'
    modal_target = True


@pagelet_config(name='user-report-properties.html', context=ISiteRoot, layer=IPyAMSLayer,
                permission=MANAGE_SYSTEM_PERMISSION)
@ajax_config(name='user-report-properties.json', context=ISiteRoot, layer=IPyAMSLayer)
class UserReportPropertiesEditForm(AdminDialogEditForm):
    """UserReport properties edit form"""

    prefix = 'user_report_properties.'

    legend = _("Update UserReport service properties")
    edit_permission = MANAGE_SYSTEM_PERMISSION

    fields = field.Fields(IUserReportInfo)
    fields['on_accepted_cookie'].widgetFactory = SingleCheckBoxFieldWidget

    label_css_class = 'control-label col-md-4'
    input_css_class = 'col-md-8'

    def updateGroups(self):
        self.add_group(NamedWidgetsGroup(self, 'cookie_accept', self.widgets,
                                         ('on_accepted_cookie', 'cookie_name', 'rejected_cookie_value'),
                                         legend=_("Activate only if not rejected cookies"),
                                         css_class='inner',
                                         help=_("If you have a cookie acceptance banner allowing your website users "
                                                "to accept or deny cookies, this extension will be activated only if "
                                                "cookies have not been rejected."),
                                         switch=True,
                                         checkbox_switch=True,
                                         checkbox_field=IUserReportInfo['on_accepted_cookie']))
        self.add_group(NamedWidgetsGroup(self, 'account_id', self.widgets,
                                         ('account_id', 'activation_mode')))
        super(UserReportPropertiesEditForm, self).updateGroups()


#
# Facebook views
#

@viewlet_config(name='facebook.menu', context=ISiteRoot, layer=IAdminLayer,
                manager=IPropertiesMenu, permission=MANAGE_SYSTEM_PERMISSION, weight=830)
class FacebookPropertiesMenuItem(MenuItem):
    """UserReport properties menu"""

    label = _("Facebook settings...")
    icon_class = 'fa-facebook'
    url = 'facebook-properties.html'
    modal_target = True


@pagelet_config(name='facebook-properties.html', context=ISiteRoot, layer=IPyAMSLayer,
                permission=MANAGE_SYSTEM_PERMISSION)
@ajax_config(name='facebook-properties.json', context=ISiteRoot, layer=IPyAMSLayer)
class FacebookPropertiesEditForm(AdminDialogEditForm):
    """Facebook properties edit form"""

    prefix = 'facebook_properties.'

    legend = _("Update Facebook application properties")
    edit_permission = MANAGE_SYSTEM_PERMISSION

    fields = field.Fields(IFacebookSiteInfo)

    label_css_class = 'control-label col-md-4'
    input_css_class = 'col-md-8'
